Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2869)

Unified Diff: chrome/browser/ui/cocoa/browser_window_controller_private.mm

Issue 2489373002: [Mac] (More) RTL support for tab strip (Closed)
Patch Set: Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/ui/cocoa/browser_window_layout.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/cocoa/browser_window_controller_private.mm
diff --git a/chrome/browser/ui/cocoa/browser_window_controller_private.mm b/chrome/browser/ui/cocoa/browser_window_controller_private.mm
index 32aad289d68b16f9135d991d25f90c34fee909d0..67b57f48a8f1fa9db674596ade0c948ac57848a6 100644
--- a/chrome/browser/ui/cocoa/browser_window_controller_private.mm
+++ b/chrome/browser/ui/cocoa/browser_window_controller_private.mm
@@ -130,7 +130,7 @@ void RecordFullscreenStyle(FullscreenStyle style) {
// This ensures the fullscreen button is appropriately positioned. It must
// be done before calling layoutSubviews because the new avatar button's
// position depends on the fullscreen button's position, as well as
- // TabStripController's rightIndentForControls.
+ // TabStripController's trailingIndentForControls.
// The fullscreen button's position may depend on the old avatar button's
// width, but that does not require calling layoutSubviews first.
NSWindow* window = [self window];
@@ -292,15 +292,16 @@ willPositionSheet:(NSWindow*)sheet
BOOL requiresRelayout =
!NSEqualRects([[self tabStripView] frame], layout.frame);
- // Check if the left indent has changed.
- if (layout.leftIndent != [tabStripController_ leftIndentForControls]) {
- [tabStripController_ setLeftIndentForControls:layout.leftIndent];
+ // Check if the leading indent has changed.
+ if (layout.leadingIndent != [tabStripController_ leadingIndentForControls]) {
+ [tabStripController_ setLeadingIndentForControls:layout.leadingIndent];
requiresRelayout = YES;
}
- // Check if the right indent has changed.
- if (layout.rightIndent != [tabStripController_ rightIndentForControls]) {
- [tabStripController_ setRightIndentForControls:layout.rightIndent];
+ // Check if the trailing indent has changed.
+ if (layout.trailingIndent !=
+ [tabStripController_ trailingIndentForControls]) {
+ [tabStripController_ setTrailingIndentForControls:layout.trailingIndent];
requiresRelayout = YES;
}
« no previous file with comments | « no previous file | chrome/browser/ui/cocoa/browser_window_layout.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698